:py:mod:`arduino_serial_out_worker`
===================================

.. py:module:: arduino_serial_out_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   arduino_serial_out_worker.initialise
   arduino_serial_out_worker.work_function
   arduino_serial_out_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   arduino_serial_out_worker.current_dir
   arduino_serial_out_worker.current_dir
   arduino_serial_out_worker.com_port
   arduino_serial_out_worker.baud_rate
   arduino_serial_out_worker.vis
   arduino_serial_out_worker.arduino_serial
   arduino_serial_out_worker.worker_object


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: com_port
   :annotation: :str

   

.. py:data:: baud_rate
   :annotation: :int

   

.. py:data:: vis
   :annotation: :bool

   

.. py:data:: arduino_serial
   :annotation: :serial.Serial

   

.. py:function:: initialise(_worker_object)


.. py:function:: work_function(data, parameters)


.. py:function:: on_end_of_life()


.. py:data:: worker_object
   

   

